<!doctype html>
{% load static %}
<html>
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Survey - {{ title }}</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <script src="https://cdn.tailwindcss.com?plugins=forms,typography,aspect-ratio,line-clamp"></script>
    {% block extra_css %}{% endblock %}
</head>
<body>
    {% if messages %}
        {% for message in messages %}
            {% include 'djf_surveys/components/alert.html' %}
        {% endfor %}
    {% endif %}
    <div class="container mx-auto">
        {% block content %} {% endblock %}
    </div>

    {% include 'djf_surveys/components/alert_js.html' %}
    {% block extra_js %}{% endblock %}
</body>
</html>