<div class="swiper-slide">
    <blockquote class="p-6 border border-gray-100 rounded-lg shadow-lg bg-white">
        {% if object.user == user %}
            <div class="flex -space-x-4 hover:space-x-1 float-right">
                {% if object.survey.editable %}
                    <a href="{% url 'djf_surveys:edit' object.id %}" class="z-20 block p-4 text-blue-700 transition-all bg-blue-100 border-2 border-white rounded-full active:bg-blue-50 hover:scale-110 focus:outline-none focus:ring"
                            type="button">
                        <svg class="w-4 h-4" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24"
                             stroke="currentColor">
                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2"
                                  d="M15.232 5.232l3.536 3.536m-2.036-5.036a2.5 2.5 0 113.536 3.536L6.5 21.036H3v-3.572L16.732 3.732z"/>
                        </svg>
                    </a>
                {% endif %}
                {% if not on_detail %}
                    <a href="{% url 'djf_surveys:detail_result' object.id %}" class="z-20 block p-4 text-green-700 transition-all bg-green-100 border-2 border-white rounded-full active:bg-green-50 hover:scale-110 focus:outline-none focus:ring"
                            type="button">
                            <svg xmlns="http://www.w3.org/2000/svg" class="h-4 w-4" fill="none" viewBox="0 0 24 24" stroke="currentColor" stroke-width="2">
                                <path stroke-linecap="round" stroke-linejoin="round" d="M15 12a3 3 0 11-6 0 3 3 0 016 0z" />
                                <path stroke-linecap="round" stroke-linejoin="round" d="M2.458 12C3.732 7.943 7.523 5 12 5c4.478 0 8.268 2.943 9.542 7-1.274 4.057-5.064 7-9.542 7-4.477 0-8.268-2.943-9.542-7z" />
                              </svg>
                    </a>
                {% endif %}
                {% if object.survey.deletable %}
                    <a class="button-delete z-30 block p-4 text-red-700 transition-all bg-red-100 border-2 border-white rounded-full hover:scale-110 focus:outline-none focus:ring active:bg-red-50"
                        data-bs-toggle="modal"
                        data-bs-target="#modalDelete"
                        data-mdb-object_name="your answer"
                        data-mdb-object_delete_url="{% url 'djf_surveys:delete' object.id %}">
                        <svg class="w-4 h-4" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24"
                             stroke="currentColor">
                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2"
                                  d="M19 7l-.867 12.142A2 2 0 0116.138 21H7.862a2 2 0 01-1.995-1.858L5 7m5 4v6m4-6v6m1-10V4a1 1 0 00-1-1h-4a1 1 0 00-1 1v3M4 7h16"/>
                        </svg>
                    </a>
                {% endif %}
            </div>
        {% endif %}
        <cite class="flex items-center mb-8 not-italic">
            <img src="{{ object.get_user_photo }}" alt="" class="object-cover w-12 h-12 rounded-full"/>

            <p class="ml-3 leading-none">
                <span class="block font-medium"> {{ object.user }} </span>
                <span class="text-sm text-gray-500"> {{ object.created_at }} </span>
            </p>
        </cite>
        <hr class="mt-3 mb-3">

        {% for answer in object.answer_set.all %}
            <p class="text-lg text-neutral-900">{{ answer.question.label }}</p>
            <p class="text-slate-400">{{ answer.get_value }}</p>
            <hr class="mt-3 mb-3">
        {% endfor %}

    </blockquote>
</div>