# Generated by Django 2.2.27 on 2022-03-30 03:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djf_surveys', '0002_auto_20220330_1033'),
    ]

    operations = [
        migrations.AlterField(
            model_name='survey',
            name='deletable',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name='survey',
            name='editable',
            field=models.BooleanField(default=True),
        ),
    ]
