    <div class="relative p-8 text-center border border-gray-200 rounded-lg">
        <h2 class="text-2xl font-medium">
            There's nothing here...
        </h2>

        <p class="mt-4 text-sm text-gray-500">
            Created survey will appear here, try creating one!
        </p>
    </div>