# Generated by Django 2.2.24 on 2022-07-21 02:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djf_surveys', '0007_auto_20220525_1126'),
    ]

    operations = [
        migrations.AlterField(
            model_name='question',
            name='choices',
            field=models.TextField(blank=True, help_text='if Type Field is (radio, select, multi select), fill in the option separated by commas. ex: Male, Female', null=True),
        ),
    ]
