<div class="datepicker" data-mdb-toggle-button="false">
    <input type="{{ widget.type }}" name="{{ widget.name }}"{% if widget.value != None %}
           value="{{ widget.value }}"{% endif %}{% include "django/forms/widgets/attrs.html" %}
           data-mdb-toggle="datepicker"/>
</div>
