# Generated by Django 2.2.27 on 2022-03-30 04:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djf_surveys', '0003_auto_20220330_1036'),
    ]

    operations = [
        migrations.AddField(
            model_name='survey',
            name='duplicate_entry',
            field=models.BooleanField(default=False, help_text='if True, user can resubmit'),
        ),
        migrations.AlterField(
            model_name='survey',
            name='deletable',
            field=models.BooleanField(default=True, help_text="if False, user can't delete record"),
        ),
        migrations.AlterField(
            model_name='survey',
            name='editable',
            field=models.BooleanField(default=True, help_text="if False, user can't edit record"),
        ),
    ]
