# Generated by Django 2.2.24 on 2022-05-25 04:26

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djf_surveys', '0006_survey_private_response'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='useranswer',
            options={'ordering': ['-updated_at']},
        ),
        migrations.AddField(
            model_name='survey',
            name='can_anonymous_user',
            field=models.BooleanField(default=False, help_text='if True, user without auth can submit'),
        ),
        migrations.AlterField(
            model_name='useranswer',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]
