# Generated by Django 2.2.27 on 2022-04-04 08:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djf_surveys', '0004_auto_20220330_1112'),
    ]

    operations = [
        migrations.AlterField(
            model_name='answer',
            name='value',
            field=models.TextField(),
        ),
    ]
