# Generated by Django 2.2.24 on 2022-05-24 01:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djf_surveys', '0005_auto_20220404_1518'),
    ]

    operations = [
        migrations.AddField(
            model_name='survey',
            name='private_response',
            field=models.BooleanField(default=False, help_text='if True, admin and owner can access'),
        ),
    ]
