# Generated by Django 2.2.27 on 2022-03-30 03:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djf_surveys', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='survey',
            name='deletable',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='survey',
            name='editable',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='question',
            name='type_field',
            field=models.PositiveSmallIntegerField(choices=[(0, 'Text'), (1, 'Number'), (2, 'Radio'), (3, 'Select'), (4, 'Multi Select'), (5, 'Text Area'), (6, 'URL'), (7, 'Email'), (8, 'Date'), (9, 'Rating')]),
        ),
    ]
